/*!
 * Built with Stencil
 * Copyright (c) Bromcom.
 */
import { r as registerInstance, c as createEvent, h, H as Host, g as getElement } from './index-0615c2b8.js';
import './color-helper-ba15b0d8.js';
import './datetime-helper-df25808a.js';
import { G as Generate } from './generate-b30859e0.js';
import './number-helper-70d15d1b.js';
import './string-helper-69203215.js';
import './validators-0ccb9921.js';
import './element-dragger-b75266e6.js';
import { B as Bcm } from './bcm-a50d55ba.js';
import { C as CaptionTemplate } from './caption-template-3cd42c3b.js';
import { c as classnames } from './index-00c8a8f7.js';
import './types-6f06fa1a.js';
import { L as LabelTemplate } from './label-template-ef97aadb.js';
import './types-9493a7ed.js';
import './colors-1d7854ea.js';
import './utils-7727d09e.js';
import './colors-ed4e7579.js';
import './_commonjsHelpers-7002e5de.js';
import './package-8f0a3af5.js';

const chipGroupCss = "@import url(\"https://fonts.googleapis.com/css?family=Roboto:400,500\");.size-1{font-size:12px;line-height:20px}.size-2{font-size:14px;line-height:22px}.size-3{font-size:16px;line-height:24px}.size-4{font-size:20px;line-height:28px}.size-5{font-size:24px;line-height:32px}.size-6{font-size:30px;line-height:38px}.size-7{font-size:38px;line-height:46px}.size-8{font-size:46px;line-height:54px}.size-9{font-size:56px;line-height:64px}.weight-regular{font-weight:400}.weight-semibold{font-weight:500}.input-size-large{height:40px}.input-size-medium{height:32px}.input-size-small{height:24px}.resize-none textarea{resize:none}.resize-vertical textarea{resize:vertical}.resize-auto textarea{height:auto;resize:none}.textarea-size-large{padding:4px 0 0 4px;min-height:40px}.textarea-size-large .bcm-input-element{min-height:calc((40px - 8px) + 2px)}.textarea-size-large .input-clear-button{height:calc( 40px - 16px );top:8px;padding:0;margin-right:8px}.textarea-size-medium{padding:4px 0 0 4px;min-height:32px}.textarea-size-medium .bcm-input-element{min-height:calc((32px - 8px) + 2px)}.textarea-size-medium .input-clear-button{height:calc( 32px - 16px );top:8px;padding:0;margin-right:8px}.textarea-size-small{padding:0px 0 0 4px;min-height:24px}.textarea-size-small .bcm-input-element{min-height:calc((24px - 8px) + 2px)}.textarea-size-small .input-clear-button{height:calc( 24px - 16px );top:8px;padding:0;margin-right:8px}.bcm-chip-group .bcm-chip{cursor:pointer}";

const BcmChipGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.change = createEvent(this, "bcm-change", 7);
    this._id = Generate.UID();
    this.name = undefined;
    this.value = undefined;
    this.required = false;
    this.size = "medium";
    this.label = undefined;
    this.caption = undefined;
    this.noCaption = false;
    this.captionType = Bcm.Status.default;
    this.captionError = undefined;
  }
  handleSelectItem(e) {
    const target = e === null || e === void 0 ? void 0 : e.target;
    if (target instanceof HTMLElement) {
      const data = e.detail;
      const chipItem = document.createElement("bcm-chip");
      // chipItem.setAttribute("type", "dismissable");
      chipItem.setAttribute("value", data.id);
      chipItem.innerHTML = data.text;
      target.parentNode.insertBefore(chipItem, target);
      this.setSelect(data.id);
    }
  }
  handleDismiss(e) {
    const target = e === null || e === void 0 ? void 0 : e.target;
    if (target instanceof HTMLElement) {
      target.remove();
      this.setSelect();
    }
  }
  handleSelect(e) {
    const target = e === null || e === void 0 ? void 0 : e.target;
    if (target instanceof HTMLElement) {
      if (target.type === "addable") {
        this.showListComponent(target.id);
      }
      else {
        this.setSelect(target.value);
      }
    }
  }
  showListComponent(id) {
    const listComponent = document.getElementById(id + "-list");
    if (listComponent) {
      listComponent.show();
    }
  }
  getSlots() {
    return this.el.querySelectorAll("bcm-chip");
  }
  setSelect(val = this.value, noEvent = false) {
    const slots = this.getSlots();
    if ((slots === null || slots === void 0 ? void 0 : slots.length) === 0)
      return;
    const slotArray = Array.from(slots);
    const selectedSlot = slotArray.find(slot => slot.value === val);
    if (!selectedSlot) {
      this.value = slotArray[0].value;
    }
    else {
      this.value = val;
    }
    slotArray.forEach(slot => {
      slot.selected = slot.value === this.value;
    });
    if (!noEvent) {
      this.change.emit(this.value);
    }
  }
  setAttr() {
    const slots = this.getSlots();
    if ((slots === null || slots === void 0 ? void 0 : slots.length) === 0)
      return;
    const slotArray = Array.from(slots);
    slotArray.forEach(slot => {
      slot.setAttribute("size", this.size);
    });
  }
  componentWillLoad() {
    this.setSelect();
  }
  componentDidRender() {
    this.setAttr();
  }
  render() {
    const { label, required, noCaption, captionType, captionError, caption } = this;
    const hostClasses = classnames("bcm-chip-group");
    return (h(Host, { class: hostClasses }, label && (h("div", null, h(LabelTemplate, { type: captionType, value: label, required: required }))), h("div", { class: "tw-flex tw-flex-wrap tw-gap-1" }, h("slot", null)), h(CaptionTemplate, { noCaption: noCaption, captionType: captionType, captionError: captionError, caption: caption })));
  }
  get el() { return getElement(this); }
};
BcmChipGroup.style = chipGroupCss;

export { BcmChipGroup as bcm_chip_group };
